@@ -8,16 +8,12 @@ if(v>n) stop(" v should be in [2, n]")
 if(v<2) stop(" v should be in [2, n]")
 
 predclass <- rep("O",n)
-#	con<-control #prueba
 
     for (i in 1:v) {
         test <- v * (0:floor(n/v)) + i
         test <- test[test < n + 1]
        fit <- bagging(formula, data[-test,],mfinal, control=control)
-#	con<<-control
-#        fit <- bagging(formula, data[-test,],mfinal, control=con)
-	fit.predict<-predict.bagging(fit, data[test,])
-        predclass[test] <- fit.predict$class
+	predclass[test] <- predict.bagging(fit, data[test,])$class
     }
 
    # para que devuelva la matriz de confusion
